define(["require", "exports", "@essential-projects/errors_ts"], function (require, exports, errors_ts_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    class FlowNodeInstanceController {
        constructor(flowNodenstanceService) {
            this.httpCodeSuccessfulResponse = 200;
            this.httpCodeSuccessfulNoContentResponse = 204;
            this.flowNodenstanceService = flowNodenstanceService;
        }
        async getAllSuspendedTasks(request, response) {
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.flowNodenstanceService.getAllSuspendedTasks(identity, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getSuspendedTasksForProcessModel(request, response) {
            const processModelId = request.params.process_model_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.flowNodenstanceService.getSuspendedTasksForProcessModel(identity, processModelId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getSuspendedTasksForProcessInstance(request, response) {
            const processInstanceId = request.params.process_instance_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.flowNodenstanceService.getSuspendedTasksForProcessInstance(identity, processInstanceId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getSuspendedTasksForCorrelation(request, response) {
            const correlationId = request.params.correlation_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.flowNodenstanceService.getSuspendedTasksForCorrelation(identity, correlationId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getSuspendedTasksForProcessModelInCorrelation(request, response) {
            const processModelId = request.params.process_model_id;
            const correlationId = request.params.correlation_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.flowNodenstanceService.getSuspendedTasksForProcessModelInCorrelation(identity, processModelId, correlationId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        parseOffset(request) {
            var _a;
            try {
                return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.offset) ? parseInt(request.query.offset) : 0;
            }
            catch (error) {
                throw new errors_ts_1.BadRequestError(`Value ${request.query.offset} is not a valid offset! Offsets must be provided as a number.`);
            }
        }
        parseLimit(request) {
            var _a;
            try {
                return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.limit) ? parseInt(request.query.limit) : 0;
            }
            catch (error) {
                throw new errors_ts_1.BadRequestError(`Value ${request.query.limit} is not a valid limit! Limits must be provided as a number.`);
            }
        }
    }
    exports.FlowNodeInstanceController = FlowNodeInstanceController;
});
//# sourceMappingURL=flow_node_instance_controller.js.map