define(["require", "exports", "@essential-projects/errors_ts"], function (require, exports, errors_ts_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    class UserTaskController {
        constructor(userTaskService) {
            this.httpCodeSuccessfulResponse = 200;
            this.httpCodeSuccessfulNoContentResponse = 204;
            this.userTaskService = userTaskService;
        }
        async getUserTasksForProcessModel(request, response) {
            const processModelId = request.params.process_model_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.userTaskService.getUserTasksForProcessModel(identity, processModelId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getUserTasksForProcessInstance(request, response) {
            const processInstanceId = request.params.process_instance_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.userTaskService.getUserTasksForProcessInstance(identity, processInstanceId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getUserTasksForCorrelation(request, response) {
            const correlationId = request.params.correlation_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.userTaskService.getUserTasksForCorrelation(identity, correlationId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getUserTasksForProcessModelInCorrelation(request, response) {
            const processModelId = request.params.process_model_id;
            const correlationId = request.params.correlation_id;
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.userTaskService.getUserTasksForProcessModelInCorrelation(identity, processModelId, correlationId, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async getWaitingUserTasksByIdentity(request, response) {
            const identity = request.identity;
            const offset = this.parseOffset(request);
            const limit = this.parseLimit(request);
            const result = await this.userTaskService.getWaitingUserTasksByIdentity(identity, offset, limit);
            response.status(this.httpCodeSuccessfulResponse).json(result);
        }
        async finishUserTask(request, response) {
            const identity = request.identity;
            const processInstanceId = request.params.process_instance_id;
            const correlationId = request.params.correlation_id;
            const userTaskInstanceId = request.params.user_task_instance_id;
            const userTaskResult = request.body;
            await this.userTaskService.finishUserTask(identity, processInstanceId, correlationId, userTaskInstanceId, userTaskResult);
            response.status(this.httpCodeSuccessfulNoContentResponse).send();
        }
        parseOffset(request) {
            var _a;
            try {
                return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.offset) ? parseInt(request.query.offset) : 0;
            }
            catch (error) {
                throw new errors_ts_1.BadRequestError(`Value ${request.query.offset} is not a valid offset! Offsets must be provided as a number.`);
            }
        }
        parseLimit(request) {
            var _a;
            try {
                return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.limit) ? parseInt(request.query.limit) : 0;
            }
            catch (error) {
                throw new errors_ts_1.BadRequestError(`Value ${request.query.limit} is not a valid limit! Limits must be provided as a number.`);
            }
        }
    }
    exports.UserTaskController = UserTaskController;
});
//# sourceMappingURL=user_task_controller.js.map