"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_ts_1 = require("@essential-projects/errors_ts");
class EmptyActivityController {
    constructor(emptyActivityService) {
        this.httpCodeSuccessfulResponse = 200;
        this.httpCodeSuccessfulNoContentResponse = 204;
        this.emptyActivityService = emptyActivityService;
    }
    async getEmptyActivitiesForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.emptyActivityService.getEmptyActivitiesForProcessModel(identity, processModelId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForProcessInstance(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.emptyActivityService.getEmptyActivitiesForProcessInstance(identity, processInstanceId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.emptyActivityService.getEmptyActivitiesForCorrelation(identity, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.emptyActivityService.getEmptyActivitiesForProcessModelInCorrelation(identity, processModelId, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getWaitingEmptyActivitiesByIdentity(request, response) {
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.emptyActivityService.getWaitingEmptyActivitiesByIdentity(identity, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async finishEmptyActivity(request, response) {
        const identity = request.identity;
        const processInstanceId = request.params.process_instance_id;
        const correlationId = request.params.correlation_id;
        const emptyActivityInstanceId = request.params.empty_activity_instance_id;
        await this.emptyActivityService.finishEmptyActivity(identity, processInstanceId, correlationId, emptyActivityInstanceId);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    parseOffset(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.offset) ? parseInt(request.query.offset) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.offset} is not a valid offset! Offsets must be provided as a number.`);
        }
    }
    parseLimit(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.limit) ? parseInt(request.query.limit) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.limit} is not a valid limit! Limits must be provided as a number.`);
        }
    }
}
exports.EmptyActivityController = EmptyActivityController;
//# sourceMappingURL=empty_activity_controller.js.map