"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_ts_1 = require("@essential-projects/errors_ts");
class EventController {
    constructor(eventService) {
        this.httpCodeSuccessfulResponse = 200;
        this.httpCodeSuccessfulNoContentResponse = 204;
        this.eventService = eventService;
    }
    async getEventsForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.eventService.getEventsForProcessModel(identity, processModelId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEventsForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.eventService.getEventsForCorrelation(identity, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEventsForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.eventService.getEventsForProcessModelInCorrelation(identity, processModelId, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async triggerMessageEvent(request, response) {
        const eventName = request.params.event_name;
        const payload = request.body;
        const identity = request.identity;
        await this.eventService.triggerMessageEvent(identity, eventName, payload);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    async triggerSignalEvent(request, response) {
        const eventName = request.params.event_name;
        const payload = request.body;
        const identity = request.identity;
        await this.eventService.triggerSignalEvent(identity, eventName, payload);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    parseOffset(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.offset) ? parseInt(request.query.offset) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.offset} is not a valid offset! Offsets must be provided as a number.`);
        }
    }
    parseLimit(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.limit) ? parseInt(request.query.limit) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.limit} is not a valid limit! Limits must be provided as a number.`);
        }
    }
}
exports.EventController = EventController;
//# sourceMappingURL=event_controller.js.map