"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_ts_1 = require("@essential-projects/errors_ts");
class ManualTaskController {
    constructor(manualTaskService) {
        this.httpCodeSuccessfulResponse = 200;
        this.httpCodeSuccessfulNoContentResponse = 204;
        this.manualTaskService = manualTaskService;
    }
    async getManualTasksForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.manualTaskService.getManualTasksForProcessModel(identity, processModelId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForProcessInstance(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.manualTaskService.getManualTasksForProcessInstance(identity, processInstanceId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.manualTaskService.getManualTasksForCorrelation(identity, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.manualTaskService.getManualTasksForProcessModelInCorrelation(identity, processModelId, correlationId, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getWaitingManualTasksByIdentity(request, response) {
        const identity = request.identity;
        const offset = this.parseOffset(request);
        const limit = this.parseLimit(request);
        const result = await this.manualTaskService.getWaitingManualTasksByIdentity(identity, offset, limit);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async finishManualTask(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const processInstanceId = request.params.process_instance_id;
        const manualTaskInstanceId = request.params.manual_task_instance_id;
        await this.manualTaskService.finishManualTask(identity, processInstanceId, correlationId, manualTaskInstanceId);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    parseOffset(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.offset) ? parseInt(request.query.offset) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.offset} is not a valid offset! Offsets must be provided as a number.`);
        }
    }
    parseLimit(request) {
        var _a;
        try {
            return ((_a = request.query) === null || _a === void 0 ? void 0 : _a.limit) ? parseInt(request.query.limit) : 0;
        }
        catch (error) {
            throw new errors_ts_1.BadRequestError(`Value ${request.query.limit} is not a valid limit! Limits must be provided as a number.`);
        }
    }
}
exports.ManualTaskController = ManualTaskController;
//# sourceMappingURL=manual_task_controller.js.map